==> web-jersey-3.3.18-sources.jar: org/smallmind/web/jersey/spring/JerseyResourceConfig.java <==
/*
 * Copyright (c) 2007, 2008, 2009, 2010, 2011, 2012, 2013, 2014, 2015, 2016, 2017, 2018, 2019 David Berkman
 * 
 * This file is part of the SmallMind Code Project.
 * 
 * The SmallMind Code Project is free software, you can redistribute
 * it and/or modify it under either, at your discretion...
 * 
 * 1) The terms of GNU Affero General Public License as published by the
 * Free Software Foundation, either version 3 of the License, or (at
 * your option) any later version.
 * 
 * ...or...
 * 
 * 2) The terms of the Apache License, Version 2.0.
 * 
 * The SmallMind Code Project is distributed in the hope that it will
 * be useful, but WITHOUT ANY WARRANTY; without even the implied warranty
 * of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * General Public License or Apache License for more details.
 * 
 * You should have received a copy of the GNU Affero General Public License
 * and the Apache License along with the SmallMind Code Project. If not, see
 * <http://www.gnu.org/licenses/> or <http://www.apache.org/licenses/LICENSE-2.0>.
 * 
 * Additional permission under the GNU Affero GPL version 3 section 7
 * ------------------------------------------------------------------
 * If you modify this Program, or any covered work, by linking or
 * combining it with other code, such other code is not for that reason
 * alone subject to any of the requirements of the GNU Affero GPL
 * version 3.
 */
package org.smallmind.web.jersey.spring;

import org.glassfish.jersey.server.ResourceConfig;
import org.smallmind.web.jersey.json.JsonProvider;
import org.springframework.context.ApplicationContext;

public class JerseyResourceConfig extends ResourceConfig {

  public JerseyResourceConfig (ApplicationContext applicationContext, ResourceConfigExtension[] extensions) {

    if (applicationContext == null) {
      throw new SpringHK2IntegrationException("Spring application context must not be 'null'");
    } else {

      HK2ResourceBeanPostProcessor hk2ResourceBeanPostProcessor;

      if ((hk2ResourceBeanPostProcessor = applicationContext.getBean(HK2ResourceBeanPostProcessor.class)) == null) {
        throw new SpringHK2IntegrationException("Spring application context must include the %s", HK2ResourceBeanPostProcessor.class.getSimpleName());
      }

      register(JsonProvider.class);

      if (extensions != null) {
        for (ResourceConfigExtension extension : extensions) {
          extension.apply(this);
        }
      }

      hk2ResourceBeanPostProcessor.registerResources(this);
    }
  }
}

==> web-jersey-3.5.0-sources.jar: org/smallmind/web/jersey/spring/JerseyResourceConfig.java <==
/*
 * Copyright (c) 2007, 2008, 2009, 2010, 2011, 2012, 2013, 2014, 2015, 2016, 2017, 2018, 2019, 2020 David Berkman
 * 
 * This file is part of the SmallMind Code Project.
 * 
 * The SmallMind Code Project is free software, you can redistribute
 * it and/or modify it under either, at your discretion...
 * 
 * 1) The terms of GNU Affero General Public License as published by the
 * Free Software Foundation, either version 3 of the License, or (at
 * your option) any later version.
 * 
 * ...or...
 * 
 * 2) The terms of the Apache License, Version 2.0.
 * 
 * The SmallMind Code Project is distributed in the hope that it will
 * be useful, but WITHOUT ANY WARRANTY; without even the implied warranty
 * of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * General Public License or Apache License for more details.
 * 
 * You should have received a copy of the GNU Affero General Public License
 * and the Apache License along with the SmallMind Code Project. If not, see
 * <http://www.gnu.org/licenses/> or <http://www.apache.org/licenses/LICENSE-2.0>.
 * 
 * Additional permission under the GNU Affero GPL version 3 section 7
 * ------------------------------------------------------------------
 * If you modify this Program, or any covered work, by linking or
 * combining it with other code, such other code is not for that reason
 * alone subject to any of the requirements of the GNU Affero GPL
 * version 3.
 */
package org.smallmind.web.jersey.spring;

import org.glassfish.jersey.server.ResourceConfig;
import org.smallmind.web.jersey.json.JsonProvider;
import org.springframework.context.ApplicationContext;

public class JerseyResourceConfig extends ResourceConfig {

  public JerseyResourceConfig (ApplicationContext applicationContext, ResourceConfigExtension[] extensions) {

    if (applicationContext == null) {
      throw new SpringIntegrationException("Spring application context must not be 'null'");
    } else {

      ResourceBeanPostProcessor resourceBeanPostProcessor;

      if ((resourceBeanPostProcessor = applicationContext.getBean(ResourceBeanPostProcessor.class)) == null) {
        throw new SpringIntegrationException("Spring application context must include the %s", ResourceBeanPostProcessor.class.getSimpleName());
      }

      register(JsonProvider.class);

      if (extensions != null) {
        for (ResourceConfigExtension extension : extensions) {
          extension.apply(this);
        }
      }

      resourceBeanPostProcessor.registerResources(this);
    }
  }
}
